Crate pcw_regrs

Modules

affine_min
This module implements an efficient algorithm for determining the pointwise minimum of a collection of affine linear functions on ℝ.
solve_dp
The part of the solution concerned with the optimal partitions and general implementation of the dynamic program.

Macros

dof
max
Find maximum of given values
min
Find minimum of given values

Structs

DegreeOfFreedom
MatchedUserParams
ScoredModel
A model for a timeseries and its CV score.
SegmentModelSpec
A specification of a model on some segment of data given by the start and stop indices w.r.t. a timeseries.
Solution
A solution of the optimization problem providing an interface to find the globally minimizing model of the CV score, the OSE optimal model and to investigate the CV and model functions.
TimeSeriesSample
UserParams
ValidTimeSeriesSample
A nonempty, NaN-free time series sample

Enums

FitError
The various kinds of errors that can happen during the polynomial fitting process.

Traits

OrdFloat
Safety
RawFloat
A marker trait that we use to wrap all the properties we internally need of a floating point type

Functions

euclid_sq_metric
Squared euclidean metric d(x,y)=‖x-y‖₂².
try_fit_pcw_poly
Fit a piecewise polynomial to the timeseries sample.

Type Aliases

CvFunc
A function mapping hyperparameter values to CV scores; each score being annotated with its standard error.
CvMinimizerModel
An optimal model minimizing the CV score.
ModelFunc
Maps each penalty γ to the corresponding optimal models given as piecewise model specifications: the arguments of the “inner” piecewise function are jump indices.
OseBestModel
An optimal model with respect to the one standard error rule.
ScoredModelFunc
Maps each penalty γ to the corresponding optimal model.